@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class ViewBreadcrumbsConfig(AppConfig):
-    name = 'view_breadcrumbs'
+    name = "view_breadcrumbs"
