@@ -11,11 +11,18 @@ class CreateBreadcrumbMixin(ListBreadcrumbMixin):
 
     @classproperty
     def create_view_name(self):
-        return action_view_name(self.model, self.create_view_suffix, full=False)
+        return action_view_name(
+            model=self.model,
+            action=self.create_view_suffix,
+            app_name=self.app_name,
+            full=False,
+        )
 
     @property
     def __create_view_name(self):
-        return action_view_name(self.model, self.create_view_suffix)
+        return action_view_name(
+            model=self.model, action=self.create_view_suffix, app_name=self.app_name
+        )
 
     @property
     def create_view_url(self):
